pub struct JobData<'a> {
pub session_data: &'a SessionData,
pub tf_mgr: TransformManager,
pub match_set_mgr: MatchSetManager,
pub group_track_manager: GroupTrackManager,
pub field_mgr: FieldManager,
pub scope_mgr: ScopeManager,
pub sv_mgr: StreamValueManager<'a>,
pub start_tf: Option<TransformId>,
pub temp_vec: Vec<u8>,
pub transform_step_count: usize,
}Fields
session_data: &'a SessionDatatf_mgr: TransformManagermatch_set_mgr: MatchSetManagergroup_track_manager: GroupTrackManagerfield_mgr: FieldManagerscope_mgr: ScopeManagersv_mgr: StreamValueManager<'a>start_tf: Option<TransformId>temp_vec: Vec<u8>transform_step_count: usizeImplementations
Sourceimpl<'a> JobData<'a>
impl<'a> JobData<'a>
pub fn new(sess: &'a SessionData) -> JobData<'a>
pub fn unlink_transform( &mut self, tf_id: TransformId, available_batch_for_successor: usize, )
pub fn get_scope_setting_or_default<S>(
&self,
scope_id: ScopeId,
) -> <S as ChainSetting>::Typewhere
S: ChainSetting,
pub fn get_setting_from_tf_state<S>(
&self,
tf_state: &TransformState,
) -> <S as ChainSetting>::Typewhere
S: ChainSetting,
pub fn get_transform_chain_from_tf_state( &self, tf_state: &TransformState, ) -> &Chain
pub fn get_transform_chain(&self, tf_id: TransformId) -> &Chain
Sourcepub fn add_actor_for_tf_state_ignore_output_field(
&self,
tf_state: &TransformState,
) -> ActorId
pub fn add_actor_for_tf_state_ignore_output_field( &self, tf_state: &TransformState, ) -> ActorId
Like add_actor_for_tf_state, but does not update the output field.
Useful for transforms without a unique output field
Sourcepub fn add_actor_for_tf_state(&self, tf_state: &TransformState) -> ActorId
pub fn add_actor_for_tf_state(&self, tf_state: &TransformState) -> ActorId
Adds an actor to the match set specified by the transform state
and applies it to the first actor entry of the output_field.
!!! This should be done before and iters
are added using claim_iter_for_tf_state, otherwise those iters
will have an incorrect ActorId for first_right_leaning_actor.
pub fn claim_iter_for_tf_state_and_field( &self, tf_state: &TransformState, field_id: FieldId, ) -> DebuggableNonMaxU32
pub fn claim_iter_ref_for_tf_state_and_field( &self, tf_state: &TransformState, field_id: FieldId, ) -> FieldIterRef
pub fn claim_iter_for_tf_state( &self, tf_state: &TransformState, ) -> DebuggableNonMaxU32
pub fn claim_iter_ref_for_tf_state( &self, tf_state: &TransformState, ) -> FieldIterRef
pub fn claim_group_track_iter_for_tf_state( &mut self, tf_state: &TransformState, ) -> GroupTrackIterRef