pub struct LengthAndCharsCountingWriter {
pub len: usize,
pub char_count: usize,
}Fields
len: usizechar_count: usizeTrait Implementations
Sourceimpl Clone for LengthAndCharsCountingWriter
impl Clone for LengthAndCharsCountingWriter
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl MaybeTextWrite for LengthAndCharsCountingWriter
impl MaybeTextWrite for LengthAndCharsCountingWriter
fn as_text_write(&mut self) -> &mut dyn TextWrite
fn as_io_write(&mut self) -> &mut dyn Write
fn deref_dyn(&mut self) -> &mut dyn MaybeTextWrite
Sourceimpl TextWrite for LengthAndCharsCountingWriter
impl TextWrite for LengthAndCharsCountingWriter
unsafe fn write_text_unchecked(&mut self, buf: &[u8]) -> Result<usize, Error>
fn flush_text(&mut self) -> Result<(), Error>
unsafe fn write_all_text_unchecked(&mut self, buf: &[u8]) -> Result<(), Error>
fn write_all_text(&mut self, buf: &str) -> Result<(), Error>
fn write_text_fmt(&mut self, args: Arguments<'_>) -> Result<(), Error>
Sourceimpl Write for LengthAndCharsCountingWriter
impl Write for LengthAndCharsCountingWriter
Sourcefn write(&mut self, buf: &[u8]) -> Result<usize, Error>
fn write(&mut self, buf: &[u8]) -> Result<usize, Error>
Writes a buffer into this writer, returning how many bytes were written. Read more
Sourcefn flush(&mut self) -> Result<(), Error>
fn flush(&mut self) -> Result<(), Error>
Flushes this output stream, ensuring that all intermediately buffered
contents reach their destination. Read more
Sourcefn is_write_vectored(&self) -> bool
fn is_write_vectored(&self) -> bool
🔬This is a nightly-only experimental API. (
can_vector)1.0.0 · Sourcefn write_all(&mut self, buf: &[u8]) -> Result<(), Error>
fn write_all(&mut self, buf: &[u8]) -> Result<(), Error>
Attempts to write an entire buffer into this writer. Read more
Sourcefn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error>
fn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error>
🔬This is a nightly-only experimental API. (
write_all_vectored)Attempts to write multiple buffers into this writer. Read more
Sourceimpl Write for LengthAndCharsCountingWriter
impl Write for LengthAndCharsCountingWriter
impl Copy for LengthAndCharsCountingWriter